pub enum Id {
Proc(ProcId),
Actor(ActorId),
Port(PortId),
}Expand description
A Hyperactor id.
Variants
Implementations
Sourceimpl Id
impl Id
Sourcepub fn as_proc_mut(&mut self) -> Option<&mut ProcId>
pub fn as_proc_mut(&mut self) -> Option<&mut ProcId>
Optionally returns mutable references to the inner fields if this is a Id::Proc, otherwise None
Sourcepub fn as_proc(&self) -> Option<&ProcId>
pub fn as_proc(&self) -> Option<&ProcId>
Optionally returns references to the inner fields if this is a Id::Proc, otherwise None
Sourcepub fn into_proc(self) -> Result<ProcId, Self>
pub fn into_proc(self) -> Result<ProcId, Self>
Returns the inner fields if this is a Id::Proc, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_actor_mut(&mut self) -> Option<&mut ActorId>
pub fn as_actor_mut(&mut self) -> Option<&mut ActorId>
Optionally returns mutable references to the inner fields if this is a Id::Actor, otherwise None
Sourcepub fn as_actor(&self) -> Option<&ActorId>
pub fn as_actor(&self) -> Option<&ActorId>
Optionally returns references to the inner fields if this is a Id::Actor, otherwise None
Sourcepub fn into_actor(self) -> Result<ActorId, Self>
pub fn into_actor(self) -> Result<ActorId, Self>
Returns the inner fields if this is a Id::Actor, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_port_mut(&mut self) -> Option<&mut PortId>
pub fn as_port_mut(&mut self) -> Option<&mut PortId>
Optionally returns mutable references to the inner fields if this is a Id::Port, otherwise None